@@ -5,9 +5,18 @@ from .utils.parser import *
 BASE_URL = Api()
 
 class Hentai2read(object):
-    """
-    A class used to represent a doujin.
+    """ Hentai2read API wrapper 
+    
+    Methods
+    -------
+    get : function
+        Gets doujin from path given
 
+    search : function
+        Search for doujin based on the latest
+
+    get_random : function
+        Gets random doujin on Hentai2read
     """
 
     def __init__(self, api_key: str = ''):
@@ -25,9 +34,9 @@ class Hentai2read(object):
         self.specs = {'api_key': self.api_key}
 
     async def get(self, path: str, chapter: int = 1):
-        """Get doujin API from Id
+        """Gets doujin from path given
 
-        path: https://hentai2read.com/a_story_of_tomoe_gozen_being_punished_by_a_shota/1/
+        path: https://hentai2read.com/a_story_of_tomoe_gozen_being_punished_by_a_shota/1
 
         Parameters
         ----------
@@ -64,7 +73,7 @@ class Hentai2read(object):
 
         self.final = json.loads(better_object(data.json()), encoding="utf-8")
    
-        if self.final["title"] is '':
+        if self.final["title"] == '':
             raise ValueError('No results. Make sure you spelled everything right.')
 
         return better_object(self.final)
@@ -94,7 +103,7 @@ class Hentai2read(object):
 
         query = auto_space(query)
 
-        if query is '':
+        if query == '':
             raise ValueError('Query must be given')
         data = requests.get(BASE_URL.hentai2read + 'args.php', params=self.specs)
 
